CREATE TABLE Office_Calendar (
	EventId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	EventType VARCHAR(50) NULL,
	EventTitle VARCHAR(200) NOT NULL,
	EventLocation VARCHAR(50) NULL,
	EventDescription LONGTEXT NULL,
	UserId VARCHAR(50) NOT NULL,
	UserName VARCHAR(100) NOT NULL,
	DeptName LONGTEXT NOT NULL,
	StartTime DATETIME NOT NULL,
	EndTime DATETIME NULL,
	IsAllDay TINYINT(1) NOT NULL DEFAULT (0),
	RecurrenceRule LONGTEXT NULL,
	AttachmentId VARCHAR(50) NULL,
	AddTime DATETIME NOT NULL DEFAULT (NOW()),
	ManagerUserId VARCHAR(50) NULL,
	ManagerUserName VARCHAR(100) NULL,
	ManagerDeptName LONGTEXT NULL,
	ManagerAttachmentId VARCHAR(50) NULL,
	ManagerSubmitDescription LONGTEXT NULL,
	ManagerSubmitTime DATETIME NULL
);

CREATE TABLE Office_Email (
	EmailId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	FromId VARCHAR (50) NOT NULL,
	FromUserName VARCHAR (100) NOT NULL,
	FromDeptName LONGTEXT NULL,
	ToId VARCHAR (50) NULL,
	ToUserName VARCHAR (100) NULL,
	ToDeptName LONGTEXT NULL,
	ToIds LONGTEXT NULL,
	Subject VARCHAR (200) NOT NULL,
	EmailContent LONGTEXT NULL,
	SendTime DATETIME NOT NULL DEFAULT (NOW()),
	AttachmentId VARCHAR (50) NULL,
	ReadFlag TINYINT(1) NOT NULL DEFAULT (0),
	DeleteFlag INT NOT NULL DEFAULT (0),
	TotalSize BIGINT NOT NULL DEFAULT (0),
	Important INT NOT NULL DEFAULT (0)
);

CREATE TABLE Office_Announcement (
	AnnouncementId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	UserId VARCHAR (50) NOT NULL,
	UserName VARCHAR (100) NOT NULL,
	DeptName LONGTEXT NULL,
	ToId VARCHAR (800) NULL,
	ToUser VARCHAR (800) NULL,
	Subject VARCHAR (200) NOT NULL,
	AnnouncementContent LONGTEXT NULL,
	SendTime DATETIME NOT NULL DEFAULT (NOW()),
	BeginDate DATETIME NULL,
	EndDate DATETIME NULL,
	AttachmentId VARCHAR (50) NULL,
	Important TINYINT(1) NOT NULL DEFAULT (0),
	ViewCount INT NULL,
	CommentCount INT NOT NULL DEFAULT (0),
	Readers LONGTEXT NULL
);

CREATE TABLE Office_Announcement_Comment (
	CommentId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	AnnouncementId BIGINT NOT NULL,
	UserId VARCHAR (50) NOT NULL,
	UserName VARCHAR (100) NOT NULL,
	DeptName LONGTEXT NULL,
	CommentContent LONGTEXT NULL,
	ReplyTime DATETIME NOT NULL DEFAULT (NOW())
);

CREATE TABLE Office_News (
	NewsId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	UserId VARCHAR (50) NOT NULL,
	UserName VARCHAR (100) NOT NULL,
	DeptName LONGTEXT NULL,
	ToId VARCHAR (4000) NULL,
	ToUser VARCHAR (4000) NULL,
	Subject VARCHAR (200) NOT NULL,
	NewsContent LONGTEXT NULL,
	SendTime DATETIME NOT NULL DEFAULT (NOW()),
	AttachmentId VARCHAR (50) NULL,
	ViewCount INT NOT NULL DEFAULT (0),
	CommentCount INT NOT NULL DEFAULT (0),
	Readers LONGTEXT NULL
);

CREATE TABLE Office_News_Comment (
	CommentId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	NewsId BIGINT NOT NULL,
	UserId VARCHAR (50) NOT NULL,
	UserName VARCHAR (100) NOT NULL,
	DeptName LONGTEXT NULL,
	CommentContent LONGTEXT NULL,
	ReplyTime DATETIME NOT NULL DEFAULT (NOW())
);

CREATE TABLE Office_WorkReport (
	ReportId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	FromUserId VARCHAR(50) NOT NULL,
	FromUserName VARCHAR(100) NOT NULL,
	FromDeptName LONGTEXT NULL,
	ToUserId VARCHAR(50) NULL,
	ToUserName VARCHAR(100) NULL,
	ToDeptName LONGTEXT NULL,
	ReportTitle VARCHAR(200) NOT NULL,
	ReportType VARCHAR(100) NOT NULL,
	ReportContent LONGTEXT NULL,
	ReportTime DATETIME NOT NULL DEFAULT (NOW()),
	AttachmentId VARCHAR(50) NULL,
	CommentContent LONGTEXT NULL,
	CommentTime DATETIME NULL,
	ReadFlag TINYINT(1) NOT NULL DEFAULT (0),
	Important TINYINT(1) NOT NULL DEFAULT (0),
	DeleteFlag INT NOT NULL DEFAULT (0)
);

CREATE TABLE Office_Wordpad (
	WordId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	UserId VARCHAR(50) NOT NULL,
	WordSubject VARCHAR(500) NOT NULL,
	WordContent LONGTEXT NOT NULL,
	WordAttachmentId VARCHAR (50) NULL,
	MoreOptions LONGTEXT NULL,
	WordTime DATETIME NOT NULL DEFAULT (NOW())
);

CREATE TABLE Office_Files (
	AttachId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	AttachType VARCHAR (50)  NOT NULL,
	AttachmentId VARCHAR (50) NOT NULL,
	Name VARCHAR (200) NOT NULL,	
	UserId VARCHAR (50) NULL,
	UserName VARCHAR (100) NULL,
	DeptName LONGTEXT NULL,
	AddTime DATETIME NOT NULL DEFAULT (NOW()),
	AddIp VARCHAR (50) NULL,
	ContentType VARCHAR (200) NULL,
	ContentLength BIGINT NOT NULL DEFAULT (0),	
	Guid VARCHAR(36) NULL DEFAULT (UUID()),
	DeleteFlag TINYINT(1) NOT NULL DEFAULT (0)
);

CREATE TABLE Team_Work (
	TeamId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	Name VARCHAR (200) NOT NULL,
	WorkContent LONGTEXT NULL,
	ToId VARCHAR (600) NULL,
	Participator VARCHAR (600) NULL,
	Manager VARCHAR (600) NULL,
	AttachmentId VARCHAR (50) NULL,
	FileAttachmentId VARCHAR (50) NULL,
	CompletedPercent INT NOT NULL DEFAULT (0),
	Status INT NOT NULL,
	CreateDate DATETIME NOT NULL DEFAULT (NOW()),
	Creator VARCHAR (50) NOT NULL,
	CreatorUserName VARCHAR (100) NOT NULL,
	CreatorDeptName LONGTEXT NULL
);

CREATE TABLE Team_Comment (
	CommentId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	CommentGuid VARCHAR(36) NOT NULL DEFAULT (UUID()),
	ParentGuid VARCHAR(36) NULL,
	TeamId BIGINT NOT NULL,
	CommentTime DATETIME NOT NULL DEFAULT (NOW()),
	CommentContent text NOT NULL,
	AttachmentId VARCHAR(50) NULL,
	CommentUserId VARCHAR(50) NULL,
	CommentUserName VARCHAR (100) NOT NULL,
	CommentDeptName LONGTEXT NULL
);

CREATE TABLE Team_Log (
	LogId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	TeamId BIGINT NOT NULL,
	LogTime DATETIME NOT NULL DEFAULT (NOW()),
	Progress VARCHAR (50) NULL,
	LogContent LONGTEXT NULL,
	AttachmentId VARCHAR (50) NULL,
	LogUserId VARCHAR (50) NOT NULL,
	LogUserName VARCHAR (100) NOT NULL,
	LogDeptName LONGTEXT NULL
);

CREATE TABLE Department (
	DeptId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	DeptNo INT NOT NULL DEFAULT (10),	
	ParentDept INT NOT NULL DEFAULT (0),
	DeptName VARCHAR (200) NOT NULL,	
	Manager VARCHAR (100) NULL,
	Leader VARCHAR (100) NULL,
	TelNo VARCHAR (50) NULL,
	DeptFunc LONGTEXT NULL
);

CREATE TABLE Flow_Files (
	AttachId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	AttachType VARCHAR (50)  NOT NULL,
	AttachmentId VARCHAR (50) NOT NULL,
	Name VARCHAR (200) NOT NULL,	
	UserId VARCHAR (50) NULL,
	UserName VARCHAR (100) NULL,
	DeptName LONGTEXT NULL,
	AddTime DATETIME NOT NULL DEFAULT (NOW()),
	AddIp VARCHAR (50) NULL,
	AddRemark LONGTEXT NULL,
	ContentType VARCHAR (200) NULL,
	ContentLength BIGINT NOT NULL DEFAULT (0),
	Guid VARCHAR(36) NULL DEFAULT (UUID()),
	DeleteFlag TINYINT(1) NOT NULL DEFAULT (0)
);

CREATE TABLE Flow_Form (
	FormId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	FormName VARCHAR(200) NOT NULL,
	FormLanguage LONGTEXT NULL,
	FormLabel VARCHAR(50) NULL,
	FormRemark LONGTEXT NULL,
	FormModel LONGTEXT NULL,	
	FormSetting LONGTEXT NULL,	
	FormScript LONGTEXT NULL,
	CssPdf LONGTEXT NULL,
	HeaderPdf LONGTEXT NULL,
	FooterPdf LONGTEXT NULL,
	CssHtml LONGTEXT NULL,
	CssDocx LONGTEXT NULL,
	DelFlag INT NOT NULL DEFAULT (0),
	IsSeal TINYINT(1) NOT NULL DEFAULT (0)
);

CREATE TABLE Flow_Type (
	FlowId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	FlowSort INT NOT NULL DEFAULT (0),
	FlowNo INT NOT NULL DEFAULT (1),
	FlowName VARCHAR (200) NOT NULL,	
	FlowType INT NOT NULL,
	FormId INT NULL,
	FormId2 INT NULL,
	FormId3 INT NULL,
	RuleOther INT NOT NULL DEFAULT (2),
	FlowDoc TINYINT(1) NOT NULL DEFAULT (0),
	NewUser VARCHAR (600) NULL,
	NewDept VARCHAR (600) NULL DEFAULT ('ALL_DEPT'),
	ManageUser VARCHAR (600) NULL,
	QueryUser VARCHAR (600) NULL,
	AutoName LONGTEXT NULL,
	AutoCounter BIGINT NOT NULL DEFAULT (0),
	AutoLen INT NOT NULL DEFAULT (0),
	AutoEdit INT NOT NULL DEFAULT (0),
	TitleItem LONGTEXT NULL,
	QueryItem LONGTEXT NULL,
	QueryExcel TINYINT(1) NOT NULL DEFAULT (1),
	DocxSplitPrint TINYINT(1) NOT NULL DEFAULT (1),
	PdfSplitPrint TINYINT(1) NOT NULL DEFAULT (1),
	PrintTemplate VARCHAR(200) NULL DEFAULT ('Signature,Attach,Comment,Diagram'),
	DelFlag INT NOT NULL DEFAULT (0),
	FlowDesc LONGTEXT NULL
);

CREATE TABLE Flow_Process (
	ProcessId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	FlowId INT NOT NULL,
	PrcsId INT NOT NULL DEFAULT (0),
	PrcsName VARCHAR (200) NOT NULL,
	PrcsGuid VARCHAR(36) NOT NULL DEFAULT (UUID()),
	FormsTitle VARCHAR(100) NULL,
	FormsId INT NULL,
	FormsVerifyType VARCHAR(20) NULL,
	FormsBeginUser LONGTEXT NULL,
	FormsRandom VARCHAR(50) NULL,
	FormsPassword VARCHAR(50) NULL,
	FormsAttach TINYINT(1) NOT NULL DEFAULT (0),
	FormsEmail VARCHAR(200),
	FormsLanguage VARCHAR(20),
	PrcsItem LONGTEXT NULL,
	AutoItem LONGTEXT NULL,
	HiddenItem LONGTEXT NULL,
	PrcsUser VARCHAR (800) NULL,
	PrcsDept VARCHAR (800) NULL DEFAULT ('ALL_DEPT'),
	PrcsTo LONGTEXT NULL,
	SetLeft INT NOT NULL DEFAULT (0),
	SetTop INT NOT NULL DEFAULT (0),
	ConditionIn LONGTEXT NULL,
	ConditionInFormula LONGTEXT NULL,
	ConditionOut LONGTEXT NULL,
	ConditionOutFormula LONGTEXT NULL,
	ConditionDesc LONGTEXT NULL,	
	Comment INT NOT NULL DEFAULT (0),
	TurnPriv INT NOT NULL DEFAULT (1),
	UserFilter INT NOT NULL DEFAULT (0),
	AutoType INT NOT NULL DEFAULT (0),
	UserLock INT NOT NULL DEFAULT (0),
	TopDefault TINYINT(1) NOT NULL DEFAULT (0),
	AutoUserOp VARCHAR (50) NULL,
	AutoUser VARCHAR (800) NULL,	
	AllowBack INT NOT NULL DEFAULT (0),
	TimeOut INT NULL,
	AttachPriv VARCHAR (50) NULL DEFAULT ('new,del,')
);

CREATE TABLE Flow_Rule (
	RuleId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	FlowId INT NULL,
	UserId VARCHAR (50) NOT NULL,
	ToId VARCHAR (50) NOT NULL,
	BeginDate DATETIME NULL,
	EndDate DATETIME NULL
);

CREATE TABLE Flow_Run (
	RunId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	RunGuid VARCHAR(36) NOT NULL DEFAULT (UUID()),
	SubRunId BIGINT NULL,
	AutoCounter BIGINT NULL,
	RunName VARCHAR (500) NOT NULL,
	FlowId INT NOT NULL,
	FlowIdOld INT NULL,
	FlowName VARCHAR (200) NOT NULL,
	FlowType INT NOT NULL,
	FormName VARCHAR(200) NOT NULL,
	FormLanguage LONGTEXT NULL,
	FormModel LONGTEXT NULL,
	FormSetting LONGTEXT NULL,
	FormCssPdf LONGTEXT NULL,
	FormHeaderPdf LONGTEXT NULL,
	FormFooterPdf LONGTEXT NULL,
	FormCssHtml LONGTEXT NULL,
	FormCssDocx LONGTEXT NULL,
	FormName2 VARCHAR(200) NULL,
	FormLanguage2 LONGTEXT NULL,
	FormModel2 LONGTEXT NULL,
	FormSetting2 LONGTEXT NULL,
	FormCssPdf2 LONGTEXT NULL,
	FormHeaderPdf2 LONGTEXT NULL,
	FormFooterPdf2 LONGTEXT NULL,
	FormCssHtml2 LONGTEXT NULL,
	FormCssDocx2 LONGTEXT NULL,
	FormName3 VARCHAR(200) NULL,
	FormLanguage3 LONGTEXT NULL,
	FormModel3 LONGTEXT NULL,
	FormSetting3 LONGTEXT NULL,
	FormCssPdf3 LONGTEXT NULL,
	FormHeaderPdf3 LONGTEXT NULL,
	FormFooterPdf3 LONGTEXT NULL,
	FormCssHtml3 LONGTEXT NULL,
	FormCssDocx3 LONGTEXT NULL,
	BeginUser VARCHAR (50) NOT NULL,
	BeginUserName VARCHAR (100) NOT NULL,
	BeginDeptName LONGTEXT NULL,
	RunTime DATETIME NOT NULL DEFAULT (NOW()),
	EndTime DATETIME NULL,
	RunIp VARCHAR (50) NULL,
	AttachmentId VARCHAR (50) NULL,
	Status INT NOT NULL DEFAULT (0),
	DelFlag INT NOT NULL DEFAULT (0),
	TeamId BIGINT NULL,
	ArchiveTime DATETIME NULL
);

CREATE TABLE Flow_Run_Data (
	DataId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	RunId BIGINT NOT NULL,
	ItemId VARCHAR (20) NOT NULL,
	ItemData LONGTEXT NULL,
	ItemPrcsId INT NULL,
	ItemPrcsName VARCHAR (200) NULL,
	ItemUserId VARCHAR (50) NULL,
	ItemUserName VARCHAR (100) NULL,
	ItemDeptName LONGTEXT NULL,
	ItemIp VARCHAR (50) NULL,
	ItemTime DATETIME NULL
);

CREATE TABLE Flow_Run_Comment (
	CommentId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	RunId BIGINT NOT NULL,
	PrcsId INT NOT NULL,
	PrcsName VARCHAR (200) NULL,
	FlowPrcs INT NOT NULL,
	UserId VARCHAR (50) NOT NULL,
	UserName VARCHAR (100) NOT NULL,
	DeptName LONGTEXT NULL,
	CommentContent LONGTEXT NULL,
	AttachmentId VARCHAR (50) NULL,
	EditTime DATETIME NOT NULL DEFAULT (NOW()),
	CommentIp VARCHAR (50) NULL
);

CREATE TABLE Flow_Run_Forms (
	FormsId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	RunId BIGINT NOT NULL,
	PrcsId INT NOT NULL,
	FlowPrcs INT NOT NULL,
	AttachmentId VARCHAR(50) NULL,
	FullName VARCHAR(50) NULL,
	Mobile VARCHAR(20) NULL,
	Email VARCHAR(200) NULL,
	SubmitIp VARCHAR(50) NULL,
	SubmitTime DATETIME NOT NULL DEFAULT (NOW())
);

CREATE TABLE Flow_Run_Prcs (
	RunPrcsId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	RunId BIGINT NOT NULL DEFAULT (0) ,
	PrcsId INT NOT NULL DEFAULT (0) ,
	PrcsName VARCHAR (200) NULL,
	FlowPrcs INT NOT NULL DEFAULT (0) ,
	HiddenItem LONGTEXT NULL,
	FormsRandom VARCHAR (50) NULL,
	FormsPassword VARCHAR (50) NULL,
	UserId VARCHAR (50) NOT NULL,
	UserName VARCHAR (100) NOT NULL,
	DeptName LONGTEXT NULL,
	PrcsTime DATETIME NULL,
	DeliverTime DATETIME NULL,
	PrcsFlag INT NOT NULL DEFAULT (1) ,
	HostFlag INT NOT NULL DEFAULT (1) ,
	TopFlag INT NOT NULL DEFAULT (0) ,
	RuleUser VARCHAR (50) NULL,
	RuleUserName VARCHAR (100) NULL,
	RuleDeptName LONGTEXT NULL,
	RuleTime DATETIME NULL,
	PrcsIp VARCHAR (50) NULL,
	TimeOut INT NULL
);

CREATE TABLE Flow_Sign (
	SignId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	SignNo INT NOT NULL,
	SignType VARCHAR (20) NULL,
	SignName VARCHAR (50) NOT NULL,
	PrivUser VARCHAR (800) NULL,
	SignData LONGTEXT NOT NULL,
	SignPassword VARCHAR (200) NULL,
	AddTime DATETIME NOT NULL DEFAULT (NOW())
);

CREATE TABLE Flow_Sort (
	SortId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	SortNo INT NOT NULL DEFAULT (0),
	SortName VARCHAR (200) NOT NULL,
	DelFlag INT NOT NULL DEFAULT (0)
);

CREATE TABLE Sys_Notification (
	NotificationId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	NotificationGuid VARCHAR(36) NOT NULL DEFAULT (UUID()),	
	FromUserId VARCHAR(50) NOT NULL,
	FromUserName VARCHAR(100) NOT NULL,
	FromDeptName LONGTEXT NULL,
	ToUserId VARCHAR(50) NOT NULL,
	ToUserName VARCHAR(50) NOT NULL,
	ToDeptName LONGTEXT NULL,
	ToEmail VARCHAR(200) NULL,
	ToEmailDone INT NULL,
	NotificationType VARCHAR(50) NULL,
	NotificationContent LONGTEXT NOT NULL,
	NotificationParameter LONGTEXT NULL,
	NotificationTime DATETIME NOT NULL DEFAULT (NOW()),
	NotificationUrl LONGTEXT NULL,
	WorkflowRunId BIGINT NULL,
	RelatedId BIGINT NULL,
	OfficialDocId BIGINT NULL,
	RemindFlag TINYINT(1) NOT NULL DEFAULT (1),
	ExtensionFlags INT NULL
);

CREATE TABLE Sys_SmsCode (
	SmsId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	MobileNumber VARCHAR(20) NOT NULL,
	SmsCode VARCHAR(10) NOT NULL,
	RequestTime DATETIME NOT NULL DEFAULT (NOW()),
	RequestIp VARCHAR(50) NULL,
	IsExpired TINYINT(1) NOT NULL DEFAULT (0)
);

CREATE TABLE Sys_Cache (
	ParaId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	ParaName VARCHAR (200) NOT NULL,
	ParaValue LONGTEXT NULL,
	ParaImage LONGBLOB NULL
);

CREATE TABLE Sys_Function (
	FuncId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	MenuId VARCHAR (50) NOT NULL,
	FuncName VARCHAR (100) NOT NULL,
	FuncCode VARCHAR (200) NOT NULL,
	FuncUrl LONGTEXT NULL,
	NewTarget TINYINT(1) NOT NULL DEFAULT (0)
);

CREATE TABLE Sys_HomeControls (
	ControlId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	ControlNo VARCHAR (10) NOT NULL,
	ControlName VARCHAR (50) NOT NULL,
	ControlPos VARCHAR (2) NOT NULL DEFAULT ('l'),
	ControlPath VARCHAR (200) NULL,
	ControlHtmlCode LONGTEXT NULL,
	CallStoredProcedure VARCHAR (200) NULL,
	ByFuncCode VARCHAR (200) NULL,
	ByUserId LONGTEXT NULL,
	IsDisplay TINYINT(1) NOT NULL DEFAULT (1)
);

CREATE TABLE Sys_Log (
	LogId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	LogType VARCHAR (50) NULL,
	UserId VARCHAR (200) NULL,
	UserName VARCHAR (100) NULL,
	DeptName LONGTEXT NULL,
	LogTime DATETIME NULL DEFAULT (NOW()),
	Ip VARCHAR (50) NULL,
	Remark LONGTEXT NULL
);

CREATE TABLE Sys_Menu (
	MenuId VARCHAR (50) NOT NULL,
	MenuName VARCHAR (100) NOT NULL
);

CREATE TABLE Sys_Org (
	Name LONGTEXT NULL,
	Address LONGTEXT NULL,
	PostCode VARCHAR (10) NULL,
	TelNo VARCHAR (100) NULL,	
	SiteUrl LONGTEXT NULL,
	Email LONGTEXT NULL,
	MoreInfo LONGTEXT NULL
);

CREATE TABLE User_Role (
	RoleId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	RoleNo INT NOT NULL DEFAULT (10),
	RoleName VARCHAR (50) NOT NULL,
	RoleIdString LONGTEXT NULL
);

CREATE TABLE Users (
	Id INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	UserId VARCHAR (50) NOT NULL,
	UserNo INT NULL DEFAULT (10),
	UserGuid VARCHAR(36) NULL DEFAULT (UUID()),
	UserName VARCHAR (100) NOT NULL,
	Password VARCHAR (200) NULL,
	RoleId INT NOT NULL DEFAULT (0),
	DeptId INT NOT NULL DEFAULT (0),
	Position VARCHAR (100) NULL,
	SecureMobile VARCHAR (50) NULL,
	Disabled TINYINT(1) NOT NULL DEFAULT (0),
	BindIp LONGTEXT NULL,	
	State INT NOT NULL DEFAULT (0),
	LastPassTime DATETIME NULL,
	LastChangePass DATETIME NULL,
	EmailCapacity INT NULL DEFAULT (-1),
	PhotoAvatar LONGTEXT NULL,
	Sex INT NOT NULL DEFAULT (1),
	Mobile VARCHAR (20) NULL,
	IsHideMobile TINYINT(1) NOT NULL DEFAULT (0),
	TelDept VARCHAR (50) NULL,
	Email VARCHAR (200) NULL,
	LinkedIn LONGTEXT NULL,
	WhatsApp LONGTEXT NULL,
	Messenger LONGTEXT NULL,
	Teams LONGTEXT NULL,
	Skype LONGTEXT NULL,
	WeChat LONGTEXT NULL,	
	Theme VARCHAR (20) NULL,
	DefaultMenu VARCHAR (10) NULL,
	NavbarView INT NOT NULL DEFAULT (1),
	NotificationAutoPop TINYINT(1) NOT NULL DEFAULT (1),
	EsignColor VARCHAR (10) NULL,
	EsignTipSize VARCHAR (10) NULL,
	Culture VARCHAR(10) NULL,
	CredentialOptions LONGTEXT NULL,
	MoreOptions LONGTEXT NULL,
	Remark LONGTEXT NULL
);

CREATE TABLE User_Token (
	TokenId BIGINT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	TokenGuid VARCHAR(36) NOT NULL DEFAULT (UUID()),
	TokenRandom VARCHAR(50) NULL,
	TokenName VARCHAR(50) NOT NULL,
	TokenUserId VARCHAR(50) NOT NULL,
	RunId BIGINT NULL,
	RunData VARCHAR(50) NULL,
	ReturnUrl LONGTEXT NULL,
	ValidTimeFrom DATETIME NOT NULL,
	ValidTimeTo DATETIME NOT NULL,
	UsedTime DATETIME NULL,
	UsedIp VARCHAR(50) NULL
);

CREATE TABLE User_Para (
	ParaId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	ParaUserId VARCHAR(50) NULL,
	ParaName VARCHAR(200) NOT NULL,
	ParaValue LONGTEXT NULL,	
	ParaTime DATETIME NOT NULL DEFAULT (NOW())
);

CREATE TABLE User_Scope (
	ScopeId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	UserId VARCHAR(50) NOT NULL,
	ScopeType VARCHAR(50) NULL,
	ScopeDepartments LONGTEXT NULL,
	ScopeUsers LONGTEXT NULL,
	ScopeRoles LONGTEXT NULL
);

CREATE TABLE Sys_Para (
	ParaId INT AUTO_INCREMENT PRIMARY KEY NOT NULL,
	ParaName VARCHAR (200) NOT NULL,
	ParaValue LONGTEXT NULL,
	Remark VARCHAR (20) NULL
);

INSERT INTO Department (DeptId,ParentDept,DeptNo,DeptName)
	VALUES (1,0,1,'缺省部门');

INSERT INTO User_Role (RoleNo,RoleName,RoleIdString)
	VALUES (1,'超级管理员',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/flow/monitor/,/flow/recover/,/flow/archiving/,/flow/form/,/flow/type/,/flow/config/sort/,/flow/config/option/,/flow/config/entrust/,/flow/config/openforms/,/flow/config/esign/,/flow/config/stamp/,/office/email/,/office/team/,/office/calendar/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,/office/mgmt/ancmt/,/office/mgmt/news/,@system,/system/org/,/system/dept/,/system/user/,/system/role/,/system/appearance/,/system/connector/,/system/menu/,/system/security/,/system/log/,/system/storage/,/system/developer/,/system/info/,');

INSERT INTO User_Role (RoleNo,RoleName,RoleIdString)
	VALUES (2,'总经理',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/flow/monitor/,/office/email/,/office/team/,/office/calendar/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,/office/mgmt/ancmt/,/office/mgmt/news/,');

INSERT INTO User_Role (RoleNo,RoleName,RoleIdString)
	VALUES (3,'员工',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/office/email/,/office/team/,/office/calendar/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,');

INSERT INTO Users (UserId,UserName,Password,RoleId,DeptId)
	VALUES ('admin','Administrator','CF83E1357EEFB8BDF1542850D66D8007D620E4050B5715DC83F4A921D36CE9CE47D0D13C5D85F2B0FF8318D2877EEC2F63B931BD47417A81A538327AF927DA3E',1,1);

CREATE INDEX IDX_Flow_Type_NewUser ON Flow_Type(NewUser);
CREATE INDEX IDX_Flow_Type_NewDept ON Flow_Type(NewDept);
CREATE INDEX IDX_Flow_Type_ManageUser ON Flow_Type(ManageUser);
CREATE INDEX IDX_Flow_Type_QueryUser ON Flow_Type(QueryUser);
CREATE INDEX IDX_Flow_Run_RunName ON Flow_Run(RunName);
CREATE INDEX IDX_Flow_Run_Prcs_FormsRandom ON Flow_Run_Prcs(FormsRandom);
CREATE INDEX IDX_Flow_Files_Name ON Flow_Files(Name);

CREATE INDEX IDX_Office_Files_Name ON Office_Files(Name);
CREATE INDEX IDX_Team_Work_ToId ON Team_Work(ToId);


